

knitrSet('multivar')



## f <- lrm(y ~ sex + race + rcs(age,5) + rcs(weight,5) +
##          rcs(height,5) + rcs(blood.pressure,5))
## plot(anova(f))



require(MASS)
sim <- function(n, sigma=2.5, pr=FALSE, prcor=FALSE) {
  x1 <- rnorm(n)
  x2 <- rnorm(n)
  x3 <- rnorm(n)
  x4 <- rnorm(n)
  x5 <- x1 + rnorm(n)/1.3
  x6 <- x2 + rnorm(n)/1.3
  x7 <- x3 + x4 + rnorm(n)
  x8 <- rnorm(n)
  if(prcor) return(round(cor(cbind(x1,x2,x3,x4,x5,x6,x7,x8)),2))
  lp <- x1 + x2 + .5*x3 + .4*x7
  y <- lp + sigma*rnorm(n)
  f <- lm(y ~ x1 + x2 + x3 + x4 + x5 + x6 + x7 + x8)
  g <- stepAIC(f, trace=0)
  p <- g$rank - 1
  xs <- if(p == 0) 'none' else 
   gsub('[ \\+x]','', as.character(formula(g))[3])
  if(pr) print(formula(g), showEnv=FALSE)
  ssesw <- sum(resid(g)^2)
  s2s <- ssesw/g$df.residual
  # Set SSEsw / (n - gdf - 1) = true sigma^2
  gdf <- n - 1 - ssesw/(sigma^2)
  list(stats=c(n=n, vratio=s2s/(sigma^2),
         gdf=gdf, apparentdf=p), xselected=xs)
}

rsim <- function(B, n) {
  xs <- character(B)
  r <- matrix(NA, nrow=B, ncol=4)
  for(i in 1:B) {
    w     <- sim(n)
    r[i,] <- w$stats
    xs[i] <- w$xselected
  }
  colnames(r) <- names(w$stats)
  s <- apply(r, 2, median)
  p <- r[,'apparentdf']
  s['apparentdf'] <- mean(p)
  print(round(s, 3))
  print(table(p))
  cat('Prob[correct model]=', round(sum(xs == '1237')/B, 2), '\n')
}



sim(50000, prcor=TRUE)



set.seed(2)
rsim(100, 20)  # actual model not selected once
rsim(100, 40)
rsim(100, 150)
rsim(100, 300)
rsim(100, 2000)






