## ----echo=FALSE----------------------------------------------------------
source('../setup.r')

## ------------------------------------------------------------------------
fig(parsurv-hr-vs-surv)  #rm#
plot(0, 0, type="n", xlab="Survival for Control Subject",
     ylab="Improvement in Survival",
     xlim=c(0,1), ylim=c(0,.7))
i <- 0
hr <- seq(.1, .9, by=.1)
for(h in hr)
{
  i <- i + 1
  p <- seq(.0001, .9999, length=200)
  p2 <- p^h
  d <- p2 - p
  lines(p, d, lty=i)
  maxd <- max(d)
  smax <- p[d==maxd]
  text(smax,maxd+.02, format(h), cex=.6)
}
doff() #rm#

## ------------------------------------------------------------------------
fig(parsurv-kprats-check, mfrow=c(2,2), h=6, w=6, bot=1, ps=9) #rm#
require(rms)
getHdata(kprats)
kprats$group <- factor(kprats$group, 0:1, c('Group 1', 'Group 2'))
dd <- datadist(kprats)
options(datadist="dd")

S <- with(kprats, Srv(t, death))
f <- npsurv(S ~ group, type="fleming", data=kprats)
survplot(f, n.risk=TRUE, conf='none',
         label.curves=list(keys='lines'), levels.only=TRUE)
title(sub="Nonparametric estimates", adj=0, cex=.7)
#par(mar=c(5,4,4,2)+.1)  #undo special rt margin used by n.risk

#Check fits of Weibull, log-logistic, log-normal
xl <- c(4.8, 5.9)
survplot(f, loglog=TRUE, logt=TRUE, conf="none", xlim=xl,
         label.curves=list(keys='lines'), levels.only=TRUE)
title(sub="Weibull (extreme value)", adj=0, cex=.7)
survplot(f, fun=function(y)log(y/(1-y)), ylab="logit S(t)", logt=TRUE, 
         conf="none", xlim=xl, label.curves=list(keys='lines'),
         levels.only=TRUE)
title(sub="Log-logistic", adj=0, cex=.7)
survplot(f, fun=qnorm, ylab="Inverse Normal S(t)",
         logt=TRUE, conf="none",
         xlim=xl,cex.label=.7, label.curves=list(keys='lines'),
         levels.only=TRUE)
title(sub="Log-normal", adj=0, cex=.7)
doff() #rm#

## ----results='asis'------------------------------------------------------
fw <- psm(S ~ group, data=kprats, dist='weibull')
fl <- psm(S ~ group, data=kprats, dist='loglogistic', y=TRUE)
fn <- psm(S ~ group, data=kprats, dist='lognormal')
latex(fw, fi='')
latex(fl, fi='')
latex(fn, fi='')

## ------------------------------------------------------------------------
fig(parsurv-kprats-psm-np) #rm#
survplot(f, conf.int=FALSE,
         levels.only=TRUE, label.curves=list(keys='lines'))
survplot(fl, add=TRUE, label.curves=FALSE, conf.int=FALSE)
doff() #rm#

## ------------------------------------------------------------------------
fig(parsurv-kprats-resid-np) #rm#
r <- resid(fl, 'cens')
survplot(npsurv(r ~ group, data=kprats),
         conf='none', xlab='Residual',
         label.curves=list(keys='lines'), levels.only=TRUE)
survplot(npsurv(r ~ 1), conf='none', add=TRUE, col='red')
lines(r, lwd=1, col='blue')
doff() #rm#

## ------------------------------------------------------------------------
fig(parsurv-kprats-hazard) #rm#
haz <- Hazard(fl)
#Plot estimated hazard functions and add median survival times to graph
survplot(fl, group, what="hazard")
med <- Quantile(fl)
m <- med(lp=predict(fl, data.frame(group=levels(kprats$group))))
m <- format(m, digits=3)
text(60, .02, paste("Group 1 median: ", m[1],"\n",
                    "Group 2 median: ", m[2], sep=""))
doff() #rm#

